==> rabbit_logger-0.1.5-py3-none-any.whl: rabbit_logger/logger/sync_handler.py <==
import datetime
import functools
import inspect
import json
import logging
import time
from uuid import uuid4

import pika

from .base_handler import BaseLoggerHandler


class SyncLoggerHandler(BaseLoggerHandler):
    def __init__(
        self, rabbit_host="localhost", rabbit_port=5672, rabbit_user="", rabbit_password="", server_name="python"
    ):
        self.connection = None
        self.channel = None
        super().__init__(rabbit_host, rabbit_port, rabbit_user, rabbit_password, server_name)

    def _ensure_connection(self):
        """
        Ленивая инициализация соединения и канала.
        """
        if not self.connection or not self.channel:
            try:
                self.connection = pika.BlockingConnection(
                    pika.ConnectionParameters(
                        host=self.host,
                        port=self.port,
                        credentials=pika.PlainCredentials(self.user, self.password),
                    )
                )
                self.channel = self.connection.channel()
                self.channel.queue_declare(queue=self.queue, durable=True)
            except Exception as e:
                self.connection = None
                self.channel = None
                logging.error(f"SyncLoggerHandler failed to initialize connection: {e}")

    def emit(self, record):
        """
        Отправляет лог-сообщение в RabbitMQ.
        """
        self._ensure_connection()
        if not self.channel:
            logging.warning("SyncLoggerHandler is not initialized properly; log message dropped.")
            return
        try:
            log_data = self.log_data(record)
            self.channel.basic_publish(
                exchange=self.exchange,
                routing_key=self.queue,
                body=json.dumps(log_data),
                properties=pika.BasicProperties(delivery_mode=2),  # Делает сообщение устойчивым
            )
        except Exception as e:
            logging.error(f"SyncLoggerHandler failed to send log: {e}")

    def close(self):
        """
        Закрывает соединение с RabbitMQ.
        """
        if self.connection:
            try:
                self.connection.close()
            except Exception as e:
                logging.error(f"SyncLoggerHandler failed to close connection: {e}")
        super().close()

    @classmethod
    def apm(cls, func):
        """
        Декоратор для сбора метрик выполнения функций.
        """

        @functools.wraps(func)
        def wrapper(*args, **kwargs):
            logger = logging.getLogger("my_app")  # Имя логгера из LOGGING
            handler = next((h for h in logger.handlers if isinstance(h, cls)), None)
            if not handler:
                raise RuntimeError(f"{cls.__name__} is not configured in the logger.")
            # Создаем временный экземпляр обработчика
            handler = cls(host="localhost", port=5672, user="user", password="password", server_name="my_server")

            func_name = func.__name__
            func_path = inspect.getsourcefile(func)
            start_time = time.time()
            try:
                result = func(*args, **kwargs)
            except Exception as e:
                raise e
            finally:
                end_time = time.time()
                data = {
                    "uuid": str(uuid4()),
                    "created_dt": datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                    "func_path": func_path,
                    "func_name": func_name,
                    "exec_time": end_time - start_time,
                }
                handler.emit(logging.makeLogRecord({"msg": data}))
                handler.close()
            return result

        return wrapper

==> rabbit_logger-0.1.6-py3-none-any.whl: rabbit_logger/logger/sync_handler.py <==
import datetime
import functools
import inspect
import json
import logging
import time
from uuid import uuid4

import pika

from .base_handler import BaseLoggerHandler


class SyncLoggerHandler(BaseLoggerHandler):
    def __init__(
        self, rabbit_host="localhost", rabbit_port=5672, rabbit_user="", rabbit_password="", server_name="python"
    ):
        self.connection = None
        self.channel = None
        super().__init__(rabbit_host, rabbit_port, rabbit_user, rabbit_password, server_name)

    def _ensure_connection(self):
        """
        Ленивая инициализация соединения и канала.
        """
        try:
            if not self.connection or self.connection.is_closed:
                self.connection = pika.BlockingConnection(
                    pika.ConnectionParameters(
                        host=self.host,
                        port=self.port,
                        credentials=pika.PlainCredentials(self.user, self.password),
                        heartbeat=60,
                        blocked_connection_timeout=30,  # Таймаут заблокированного соединения
                    )
                )
            if not self.channel or self.channel.is_closed:
                self.channel = self.connection.channel()
                self.channel.queue_declare(queue=self.queue, durable=True)
        except Exception as e:
            self.connection = None
            self.channel = None
            logging.error(f"SyncLoggerHandler failed to initialize connection: {e}")

    def emit(self, record):
        """
        Отправляет лог-сообщение в RabbitMQ.
        """
        self._ensure_connection()
        if not self.channel:
            logging.warning("SyncLoggerHandler is not initialized properly; log message dropped.")
            return
        try:
            log_data = self.log_data(record)
            self.channel.basic_publish(
                exchange=self.exchange,
                routing_key=self.queue,
                body=json.dumps(log_data),
                properties=pika.BasicProperties(delivery_mode=2),  # Делает сообщение устойчивым
            )
        except Exception as e:
            logging.error(f"SyncLoggerHandler failed to send log: {e}")
            self.connection = None

    def close(self):
        """
        Закрывает соединение с RabbitMQ.
        """
        if self.connection:
            try:
                self.connection.close()
            except Exception as e:
                logging.error(f"SyncLoggerHandler failed to close connection: {e}")
        super().close()

    @classmethod
    def apm(cls, func):
        """
        Декоратор для сбора метрик выполнения функций.
        """

        @functools.wraps(func)
        def wrapper(*args, **kwargs):
            logger = logging.getLogger("my_app")  # Имя логгера из LOGGING
            handler = next((h for h in logger.handlers if isinstance(h, cls)), None)
            if not handler:
                raise RuntimeError(f"{cls.__name__} is not configured in the logger.")
            # Создаем временный экземпляр обработчика
            handler = cls(host="localhost", port=5672, user="user", password="password", server_name="my_server")

            func_name = func.__name__
            func_path = inspect.getsourcefile(func)
            start_time = time.time()
            try:
                result = func(*args, **kwargs)
            except Exception as e:
                raise e
            finally:
                end_time = time.time()
                data = {
                    "uuid": str(uuid4()),
                    "created_dt": datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                    "func_path": func_path,
                    "func_name": func_name,
                    "exec_time": end_time - start_time,
                }
                handler.emit(logging.makeLogRecord({"msg": data}))
                handler.close()
            return result

        return wrapper
